@@ -318,6 +318,12 @@ void File_Aac::FileHeader_Parse_ADIF()
 // Buffer - Global
 //***************************************************************************
 
+//---------------------------------------------------------------------------
+void File_Aac::Read_Buffer_Init()
+{
+    File_Usac::Read_Buffer_Init();
+}
+
 //---------------------------------------------------------------------------
 void File_Aac::Read_Buffer_Continue()
 {
