@@ -495,7 +495,7 @@ extern string Aac_ChannelMode_GetString(const Aac_OutputChannel* const OutputCha
     memset(ChannelModes, 0, Aac_ChannelMode_Max+1);
     for (int i=0; i<OutputChannels_Size; i++)
     {
-        if (OutputChannels[i]>Aac_OutputChannelPosition_Size)
+        if (OutputChannels[i]>=Aac_OutputChannelPosition_Size)
             ChannelModes[Aac_ChannelMode_Max]++;
         else
             ChannelModes[Aac_ChannelMode[OutputChannels[i]]]++;
