@@ -90,10 +90,12 @@ namespace Elements
     const int32u IHDR=0x49484452;
     const int32u PLTE=0x506C5445;
     const int32u cICP=0x63494350;
+    const int32u cLLI=0x634C4C49;
     const int32u cLLi=0x634C4C69;
     const int32u gAMA=0x67414D41;
     const int32u iCCP=0x69434350;
     const int32u iTXt=0x69545874;
+    const int32u mDCV=0x6D444356;
     const int32u mDCv=0x6D444376;
     const int32u pHYs=0x70485973;
     const int32u sBIT=0x73424954;
@@ -255,10 +257,12 @@ void File_Png::Data_Parse()
         CASE_INFO(IHDR,                                         "Image header");
         CASE_INFO(PLTE,                                         "Palette table");
         CASE_INFO(cICP,                                         "Coding-independent code points");
+        CASE_INFO(cLLI,                                         "Content Light Level Information");
         CASE_INFO(cLLi,                                         "Content Light Level Information");
         CASE_INFO(gAMA,                                         "Gamma");
         CASE_INFO(iCCP,                                         "Embedded ICC profile");
         CASE_INFO(iTXt,                                         "International textual data");
+        CASE_INFO(mDCV,                                         "Mastering Display Color Volume");
         CASE_INFO(mDCv,                                         "Mastering Display Color Volume");
         CASE_INFO(pHYs,                                         "Physical pixel dimensions");
         CASE_INFO(sBIT,                                         "Significant bits");
@@ -373,7 +377,7 @@ void File_Png::cICP()
 }
 
 //---------------------------------------------------------------------------
-void File_Png::cLLi()
+void File_Png::cLLI()
 {
     //Parsing
     Ztring MaxCLL, MaxFALL;
@@ -473,7 +477,7 @@ void File_Png::iCCP()
 }
 
 //---------------------------------------------------------------------------
-void File_Png::mDCv()
+void File_Png::mDCV()
 {
     Ztring MasteringDisplay_ColorPrimaries, MasteringDisplay_Luminance;
     Get_MasteringDisplayColorVolume(MasteringDisplay_ColorPrimaries, MasteringDisplay_Luminance);
