@@ -14,8 +14,60 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/Setup.h"
+#include <algorithm>
+#include <iterator>
+#include <string>
+using namespace std;
 //---------------------------------------------------------------------------
 
+
+//***************************************************************************
+// Constants
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+#if defined(MEDIAINFO_MPEG7_YES)
+//---------------------------------------------------------------------------
+
+namespace MediaInfoLib
+{
+
+//---------------------------------------------------------------------------
+static constexpr const char* ProRes_Profile_Names[]= // Time sorted list
+{
+    "422 Proxy",                        // 2007
+    "422 LT",
+    "422",
+    "422 HQ",
+    "4444",                             // 2009
+    "4444 XQ",
+    "RAW",                              // 2018
+    "RAW HQ"
+};
+const char* ProRes_Profile_Name(size_t Index)
+{
+    return ProRes_Profile_Names[Index];
+}
+size_t ProRes_Profile_Index(const string& ProfileS) // Note: 1-based, 0 means not found
+{
+    size_t Profile;
+    auto Pos=find(begin(ProRes_Profile_Names), end(ProRes_Profile_Names), ProfileS);
+    if (Pos==end(ProRes_Profile_Names))
+        return 0;
+    return distance(begin(ProRes_Profile_Names), Pos)+1;
+}
+
+//---------------------------------------------------------------------------
+} //NameSpace
+
+//---------------------------------------------------------------------------
+#endif //...
+//---------------------------------------------------------------------------
+
+//***************************************************************************
+//
+//***************************************************************************
+
 //---------------------------------------------------------------------------
 #if defined(MEDIAINFO_PRORES_YES)
 //---------------------------------------------------------------------------
